Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(20)

Unified Diff: src/arm64/code-stubs-arm64.cc

Issue 2244673002: [regexp][liveedit] Fix inconsistent JSArrays (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/arm/code-stubs-arm.cc ('k') | src/debug/liveedit.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/arm64/code-stubs-arm64.cc
diff --git a/src/arm64/code-stubs-arm64.cc b/src/arm64/code-stubs-arm64.cc
index 5baf14eb83bab3044d4b0454a4d87c5e48381be7..5f103bc20cff96eac5db90a384700b23660bcf12 100644
--- a/src/arm64/code-stubs-arm64.cc
+++ b/src/arm64/code-stubs-arm64.cc
@@ -1648,15 +1648,15 @@ void RegExpExecStub::Generate(MacroAssembler* masm) {
__ Add(x10, x10, x10);
__ Add(number_of_capture_registers, x10, 2);
// Check that the fourth object is a JSArray object.
DCHECK(jssp.Is(__ StackPointer()));
__ Peek(x10, kLastMatchInfoOffset);
__ JumpIfSmi(x10, &runtime);
- __ JumpIfNotObjectType(x10, x11, x11, JS_ARRAY_TYPE, &runtime);
+ __ JumpIfNotObjectType(x10, x11, x11, JS_OBJECT_TYPE, &runtime);
- // Check that the JSArray is the fast case.
+ // Check that the object has fast elements.
__ Ldr(last_match_info_elements,
- FieldMemOperand(x10, JSArray::kElementsOffset));
+ FieldMemOperand(x10, JSObject::kElementsOffset));
__ Ldr(x10,
FieldMemOperand(last_match_info_elements, HeapObject::kMapOffset));
__ JumpIfNotRoot(x10, Heap::kFixedArrayMapRootIndex, &runtime);
@@ -1648,15 +1648,15 @@ void RegExpExecStub::Generate(MacroAssembler* masm) {
__ Add(x10, x10, x10);
__ Add(number_of_capture_registers, x10, 2);
- // Check that the fourth object is a JSArray object.
+ // Check that the fourth object is a JSObject.
DCHECK(jssp.Is(__ StackPointer()));
__ Peek(x10, kLastMatchInfoOffset);
« no previous file with comments | « src/arm/code-stubs-arm.cc ('k') | src/debug/liveedit.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698